@@ -35,95 +35,95 @@
    then it is added to the history.
    If no query parameter is given, the window is displayed,
    containing no "result box".
-[Fonc]*)
+   [Fonc]*)
 let rec window context ?(query : string option) () =
-  try     
-    let (n, columns, records) = 
+  try
+    let (n, columns, records) =
       match query with
-	None ->
-	  (0, [], [])
+        None ->
+          (0, [], [])
       | Some q ->
-	  context#database#execute_with_info q
+          context#database#execute_with_info q
     in
     if n = 0 then
       (
        (* the query, if any, was successfully executed ; add it to the history *)
-       let _ = 
-	 match query with
-	   None -> ()
-	 | Some q -> context#add_query q
+       let _ =
+         match query with
+           None -> ()
+         | Some q -> context#add_query q
        in
        (* create the window if there are results to display or
-	  it is the initial window (no query) *)
+          it is the initial window (no query) *)
        match columns with
-	 [] when query <> None ->
-	   (* no result *)
-	   ()
+         [] when query <> None ->
+           (* no result *)
+           ()
        | _ ->
            (* create the window *)
-	   let win = GWindow.window
-	       ~title: (Biniki_messages.logiciel^" "^Biniki_messages.version^" : "^context#base)
-	       ~width:500 ()
-	   in
-	   let _ = win#connect#destroy ~callback: GMain.Main.quit in
-	   
+           let win = GWindow.window
+             ~title: (Biniki_messages.logiciel^" "^Biniki_messages.version^" : "^context#base)
+               ~width:500 ()
+           in
+           let _ = win#connect#destroy ~callback: GMain.Main.quit in
+
            (* The main box *)
-	   let vbox = GPack.vbox ~packing:win#add () in
+           let vbox = GPack.vbox ~packing:win#add () in
            (* The ... menubar ! *)
-	   let menubar = GMenu.menu_bar ~packing: (vbox#pack ~expand: false) () in
-	   let menuFile = GMenu.menu () in
-	   let itemFile = GMenu.menu_item ~label: Biniki_messages.mn1 ~packing: menubar#add () in
-	   let _ = itemFile#set_submenu menuFile in
-	   let itemClose = GMenu.menu_item ~label: Biniki_messages.mn2
-	       ~packing: menuFile#add ()
-	   in
-	   let _ = itemClose#connect#activate win#destroy in
+           let menubar = GMenu.menu_bar ~packing: (vbox#pack ~expand: false) () in
+           let menuFile = GMenu.menu () in
+           let itemFile = GMenu.menu_item ~label: Biniki_messages.mn1 ~packing: menubar#add () in
+           let _ = itemFile#set_submenu menuFile in
+           let itemClose = GMenu.menu_item ~label: Biniki_messages.mn2
+             ~packing: menuFile#add ()
+           in
+           let _ = itemClose#connect#activate win#destroy in
 
-	   let menuHelp = GMenu.menu () in
-	   let itemHelp = GMenu.menu_item ~label: Biniki_messages.mn3 ~packing: menubar#add () in
-	   let _ = itemHelp#set_submenu menuHelp in
-	   let itemAbout = GMenu.menu_item ~label: Biniki_messages.mn4
-	       ~packing: menuHelp#add ()
-	   in
-	   let _ = itemAbout#connect#activate
-	       (fun () -> Biniki_misc.message_box Biniki_messages.mn4 Biniki_messages.mAbout)
-	   in
+           let menuHelp = GMenu.menu () in
+           let itemHelp = GMenu.menu_item ~label: Biniki_messages.mn3 ~packing: menubar#add () in
+           let _ = itemHelp#set_submenu menuHelp in
+           let itemAbout = GMenu.menu_item ~label: Biniki_messages.mn4
+             ~packing: menuHelp#add ()
+           in
+           let _ = itemAbout#connect#activate
+             (fun () -> Biniki_misc.message_box Biniki_messages.mn4 Biniki_messages.mAbout)
+           in
 
-	   let _ =
-	     match query with
-	       None -> ()
-	     | Some q ->
+           let _ =
+             match query with
+               None -> ()
+             | Some q ->
                  (* add the query box *)
-		 let query_box = new Biniki_query_box.box context ~query: q columns records in
-		 let _ = vbox#pack ~expand: true query_box#box in
-		 ()
-	   in
+                 let query_box = new Biniki_query_box.box context ~query: q columns records in
+                 let _ = vbox#pack ~expand: true query_box#box in
+                 ()
+           in
 
            (* the box for the combo and the execute-button *)
-	   let hbox = GPack.hbox ~packing: (vbox#pack ~expand: false ~padding: 2) () in
+           let hbox = GPack.hbox ~packing: (vbox#pack ~expand: false ~padding: 2) () in
            (* The combo box for queries *)
-	   let wcombo_queries = GEdit.combo
-	       ~popdown_strings: ("" :: context#history_queries)
-	       ~value_in_list: false
-	       ~ok_if_empty: true
-	       ~packing: (hbox#pack ~expand: true ~padding: 2)
-	       ()
-	   in
-	   let wb_execute = GButton.button
-	       ~label: Biniki_messages.mExecute
-	       ~packing: (hbox#pack ~expand: false ~padding: 2)
-	       ()
-	   in
-	   
-	   (* the function called to execute the query in the combo *)
-	   let f_exec_query () =
-	     let string_query = wcombo_queries#entry#text in
-	     window context ~query: string_query ()
-	   in
-	   let _ = wb_execute#connect#clicked f_exec_query in
+           let wcombo_queries = GEdit.combo
+             ~popdown_strings: ("" :: context#history_queries)
+               ~value_in_list: false
+               ~allow_empty: true
+               ~packing: (hbox#pack ~expand: true ~padding: 2)
+               ()
+           in
+           let wb_execute = GButton.button
+             ~label: Biniki_messages.mExecute
+               ~packing: (hbox#pack ~expand: false ~padding: 2)
+               ()
+           in
 
-	   win#show ();
-	   GMain.Main.main ()
+           (* the function called to execute the query in the combo *)
+           let f_exec_query () =
+             let string_query = wcombo_queries#entry#text in
+             window context ~query: string_query ()
+           in
+           let _ = wb_execute#connect#clicked f_exec_query in
+
+           win#show ();
+           GMain.Main.main ()
       )
     else
       Biniki_misc.message_box Biniki_messages.mErreur Biniki_messages.m0
